@@ -1,7 +1,9 @@
-context("build-news.R")
+context("test-build-news.R")
 
 test_that("github links are added to news items", {
-  path <- test_path("news-github-links")
+  skip_if_no_pandoc()
+
+  path <- test_path("assets/news-github-links")
   pkg <- as_pkgdown(path)
   news_tbl <- data_news(pkg)
 
@@ -13,14 +15,18 @@ test_that("github links are added to news items", {
 })
 
 test_that("build_news() uses content in NEWS.md", {
-  pkg <- test_path("news")
+  skip_if_no_pandoc()
+
+  pkg <- test_path("assets/news")
 
   expect_output(build_news(pkg))
   on.exit(clean_site(pkg))
 
   lines <- read_lines(path(pkg, "docs", "news", "index.html"))
-  test_strings <- c("testpackage", "1.0.0.9000", "1.0.0[^\\.]",
-                    "sub-heading", "@githubuser", "bullet", "#111")
+  test_strings <- c(
+    "testpackage", "1.0.0.9000", "1.0.0[^\\.]",
+    "sub-heading", "@githubuser", "bullet", "#111"
+  )
   expect_true(all(
     vapply(test_strings, function(x) any(grepl(x, lines)), logical(1))
   ))
@@ -42,5 +48,20 @@ test_that("correct timeline for first ggplot2 releases", {
   )
 
   expect_equal(timeline, expected)
+})
 
+test_that("multi-page news are rendered", {
+  skip_if_no_pandoc()
+
+  path <- test_path("assets/news-multi-page")
+  pkg <- as_pkgdown(path)
+  expect_output(build_news(pkg))
+
+  # test that index links are correct
+  lines <- read_lines(path(path, "docs", "news", "index.html"))
+  expect_true(any(grepl("<a href=\"news-2.0.html\">Version 2.0</a>", lines)))
+
+  # test single page structure
+  lines <- read_lines(path(path, "docs", "news", "news-1.0.html"))
+  expect_true(any(grepl("<h1>Changelog <small>1.0</small></h1>", lines)))
 })
